#
# spec file for package mathmod
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define binname MathMod
Name:           mathmod
Version:        12.0
Release:        1.2
Summary:        Mathematical modelling to visualise implicit and parametric surfaces
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://sourceforge.net/projects/mathmod/
Source0:        http://sourceforge.net/projects/mathmod/files/MathMod-%{version}/%{name}-%{version}-source.zip
Source1:        %{name}.desktop
BuildRequires:  ImageMagick
BuildRequires:  dos2unix
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  unzip
BuildRequires:  pkgconfig(Qt5Core) >= 5.12.0
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5Widgets)

%description
MathMod is a mathematical modeling software to model, plot and animate
3D/4D parametric and implicit surfaces.

Features:
 * 3D and 4D plotting and animation
 * OBJ output file format
 * Scripting language in JSON file format
 * Texture and pigmentation support
 * Noise and Turbulence effects support
 * Large set of scripted examples

%prep
%setup -q -n %{name}-%{version}

dos2unix -k Readme.txt

%build
mkdir build
pushd build
%qmake5 ../%{binname}.pro
%make_jobs
popd

%install
install -d %{buildroot}%{_bindir}
install -d %{buildroot}%{_datadir}/pixmaps
install -Dm 0755 build/%{binname} %{buildroot}%{_libdir}/%{name}/%{name}
ln -s %{_libdir}/%{name}/%{name} %{buildroot}%{_bindir}/%{name}
for f in $(find -maxdepth 1 -name \*.js); do
j=$(basename $f)
install -Dm 0644 $f %{buildroot}%{_libdir}/%{name}/$j
done
for i in $(find images/icon -name \*.png); do
r=$(echo $i|sed 's/[^0-9x]//g')
install -Dm 0644 $i %{buildroot}%{_datadir}/icons/hicolor/${r}/apps/%{name}.png
done
convert -monitor images/icon/catenoid_mini_64x64.ico %{buildroot}%{_datadir}/pixmaps/%{name}.xpm
# Remove spurious icon file
rm %{buildroot}%{_datadir}/icons/hicolor/apps/mathmod.png

install -Dm 0644 %{SOURCE1} %{buildroot}%{_datadir}/applications/%{name}.desktop

%files
%license Licence.txt
%doc Readme.txt
%{_bindir}/%{name}
%{_libdir}/%{name}/
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/pixmaps/%{name}.xpm
%{_datadir}/applications/%{name}.desktop

%changelog
* Fri Dec 20 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 12.0:
  * GUI improvement to support small screen formats
  - Merged MathMod's two main windows into one
  - Added touch gestures support
  - Multi cores calculations optimization for embedded systems
  * Mandelbrot and Julia fractal functions support
  * New scripts: "Noids", "k_Noids", "Riemann_Minimal_Surface",
    "MandelBulb", "MandelTemple", "JuliaFractal",
    "MandelbrotTorus", "MandelbrotIsoSpheres", "MandelbrotSphere",
    "Mandelbrot", "Spherical_Harmonics"
  * Bug-fixes, code optimization and documentation update.
- Drop use of deprecated %%suse_update_desktop_files macro.
- Add mathmod.desktop file as additional source in lieu of the
  dropped %%suse_update_desktop_files macro.
* Tue Feb  8 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 11.1:
  * Support of graphing functions with complex numbers Z=u+iv in
    3D and 4D spaces (demo scripts: "Complex3D_xx" and
    "Complex4D_Saddle").
  * Added support for HSV (hue, saturation, lightness) coloring
    model (script: "Complex_Domain_Coloring").
  * Texture definitions (RGB and HSV) for parametric surfaces can
    now be expressed as functions of complex numbers.
  * Added a software implementation for the OpenGL variable
    gl_FrontFacing.
  * Bug-fixes, code optimization and documentation update.
- Drop qt512_no_markdown.patch: incorporated upstream.
- Drop a spurious icon file installed to an incorrect location.
* Thu May 13 2021 Predrag Ivanović <predivan@mts.rs>
- Update to version 11.0:
  Summary of changes from 6.0 to 11.0
  * Complete rewrite of OpenGL viewer in order to make it OpenGl ES compatible:
    MathMod can now run (or easily adaptable to run) on mobile systems and platforms with limited resources, like RaspberryPi.
  * Add: possibility to show/hide a selected component , two new scripts ("Groupings of Knots" , "Knotted Möbius strips") and OpenGL diffuse/ambient lights setting.
  * Add user defined variables to reduce processing time.
  * Add Texture support for new parameters, possibility to resize up/down the exported meshes, OpenGL specular and shininess setting in the configuration file.
  * Support for mathematical objects made up of parametric and implicit surfaces.
  * Scripts calculations enhancement for parametric and implicit surfaces.
  * Added text information window to give the user an indication of the progress of an operation(threads number, processing time...)
  * Automatic detection and allocation of the right number of threads supported by the hardware.
    (you can however set a desired number of threads from mathmodconfig.js).
  * Add new tool for scripts selection on one or multiple JSON scripts fields.
  * Add option to export OBJ files with vertex colours.
  * Add new scripts to generate math models with chained patterns (Chained Cylinder/Sinusoid).
  * Add support for complex scripts involving more than 100 functions declarations (previous versions were practically limited to less than 12 functions declarations).
  * Bug-fixes, code optimization and documentation update.
- Package changes:
  * Add qt512_no_markdown.patch
    Disable Markdown support for Leap in the editor, since it was added to QtTextEdit in QT-5.14.
    and Leap ships Qt-5.12.
  * Spec-cleaner run and build fixes.
  * Change license to GPL-2, as per License file in the source tree.
* Wed Sep 13 2017 badshah400@gmail.com
- Update to version 6.0:
  * Multicores calculation support.
  * MathMod's viewer improvement: Add possibility to load vertices
    on the OpenGl's server side.
  * Add OpenGl specular & shininess parameters.
  * Code/scripts cleaning and optimization.
* Fri Aug 18 2017 badshah400@gmail.com
- Update to version 5.0:
  * Add feature to record successive screenshots (frames)
  * Add support for using u and v parameters in solid textures
    descriptions (for parametric surfaces).
  * Add 32 new scripts for a total of 373 integrated scripts.
  * Bug fix and code optimization.
* Mon Jan 18 2016 avvissu@yandex.ru
- Initial build
